pub struct AggregatePlugin { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world aggregate-plugin.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
AggregatePlugin::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
AggregatePluginPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesAggregatePluginPre::instantiateto create aAggregatePlugin. -
If you’ve instantiated the instance yourself already then you can use
AggregatePlugin::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl AggregatePlugin
impl AggregatePlugin
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<AggregatePlugin>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<AggregatePlugin>
Convenience wrapper around AggregatePluginPre::new and
AggregatePluginPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<AggregatePlugin>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<AggregatePlugin>
Convenience wrapper around AggregatePluginIndices::new and
AggregatePluginIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<AggregatePlugin>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<AggregatePlugin>where
_T: Send,
Convenience wrapper around AggregatePluginPre::new and
AggregatePluginPre::instantiate_async.
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>
pub fn call_manifest<S: AsContextMut>(&self, store: S) -> Result<String>
pub fn call_register<S: AsContextMut>(&self, store: S) -> Result<String>
Sourcepub fn call_agg_new<S: AsContextMut>(
&self,
store: S,
arg0: &str,
) -> Result<Result<Vec<u8>, FnError>>
pub fn call_agg_new<S: AsContextMut>( &self, store: S, arg0: &str, ) -> Result<Result<Vec<u8>, FnError>>
Initial state for a fresh per-group accumulator.
Sourcepub fn call_agg_update<S: AsContextMut>(
&self,
store: S,
arg0: &str,
arg1: &[u8],
arg2: &[u8],
) -> Result<Result<Vec<u8>, FnError>>
pub fn call_agg_update<S: AsContextMut>( &self, store: S, arg0: &str, arg1: &[u8], arg2: &[u8], ) -> Result<Result<Vec<u8>, FnError>>
Ingest values-ipc into the accumulator at state. Returns
the new state bytes.
Sourcepub fn call_agg_merge<S: AsContextMut>(
&self,
store: S,
arg0: &str,
arg1: &[u8],
arg2: &[u8],
) -> Result<Result<Vec<u8>, FnError>>
pub fn call_agg_merge<S: AsContextMut>( &self, store: S, arg0: &str, arg1: &[u8], arg2: &[u8], ) -> Result<Result<Vec<u8>, FnError>>
Merge other-states-ipc (an Arrow IPC stream with one
Binary column) into the accumulator at state.
Sourcepub fn call_agg_evaluate<S: AsContextMut>(
&self,
store: S,
arg0: &str,
arg1: &[u8],
) -> Result<Result<Vec<u8>, FnError>>
pub fn call_agg_evaluate<S: AsContextMut>( &self, store: S, arg0: &str, arg1: &[u8], ) -> Result<Result<Vec<u8>, FnError>>
Produce the final aggregate value as a 1-row × 1-col Arrow IPC stream.