pub struct ProcedurePlugin { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world procedure-plugin.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
ProcedurePlugin::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
ProcedurePluginPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesProcedurePluginPre::instantiateto create aProcedurePlugin. -
If you’ve instantiated the instance yourself already then you can use
ProcedurePlugin::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl ProcedurePlugin
impl ProcedurePlugin
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ProcedurePlugin>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<ProcedurePlugin>
Convenience wrapper around ProcedurePluginPre::new and
ProcedurePluginPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<ProcedurePlugin>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<ProcedurePlugin>
Convenience wrapper around ProcedurePluginIndices::new and
ProcedurePluginIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ProcedurePlugin>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ProcedurePlugin>where
_T: Send,
Convenience wrapper around ProcedurePluginPre::new and
ProcedurePluginPre::instantiate_async.
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>
pub fn call_manifest<S: AsContextMut>(&self, store: S) -> Result<String>
pub fn call_register<S: AsContextMut>(&self, store: S) -> Result<String>
pub fn call_invoke_procedure<S: AsContextMut>( &self, store: S, arg0: &str, arg1: &[u8], ) -> Result<Result<Vec<u8>, FnError>>